DmaAlignedMut

Struct DmaAlignedMut 

pub struct DmaAlignedMut<'a, T>(/* private fields */)
where
    T: ?Sized;
Available on crate feature unstable only.
A mutable reference to an InternalMemory object.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl<'a, T: ?Sized> DmaAlignedMut<'a, T>

pub fn new(ptr: &'a mut T) -> Result<Self, DmaBufError>

Creates a new DmaAlignedMut from a mutable variable, if it’s provably compatible.

In internal memory, the address and size of the variable must be at least 4 byte aligned.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub const unsafe fn new_unchecked(ptr: &'a mut T) -> Self

Creates a new DmaAlignedMut from any mutable slice.

Safety

The caller must ensure that the reference is properly aligned for the memory region it occupies and the cachelines occupied by the reference do not overlap with any other data that can be corrupted by a cacheline invalidation operation.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn into_inner(self) -> &'a mut T

Converts this object into a mutable reference.

pub fn reborrow<'b>(&'b mut self) -> DmaAlignedMut<'b, T>

Reborrows this object with a different lifetime.

Source

impl<'a, T, const N: usize> DmaAlignedMut<'a, [T; N]>

pub fn unsize(self) -> DmaAlignedMut<'a, [T]>

Converts this object into a slice reference.